summaryrefslogtreecommitdiff
path: root/utils.c
diff options
context:
space:
mode:
authorDavid Sterba <dsterba@suse.com>2016-03-24 19:17:53 +0100
committerDavid Sterba <dsterba@suse.com>2016-03-30 16:26:33 +0200
commit41f6ae4820b7c288a6688086bd1a61687a50e3f3 (patch)
treed85cb3cee319e766cbdd8485947ba736342904c3 /utils.c
parentc7f72072bd727914bceba74a31dfbb00ffdf069f (diff)
btrfs-progs: rename __strncpy__null to __strncpy_null
Signed-off-by: David Sterba <dsterba@suse.com>
Diffstat (limited to 'utils.c')
-rw-r--r--utils.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/utils.c b/utils.c
index 0ba4ecbc..e057cf3e 100644
--- a/utils.c
+++ b/utils.c
@@ -1683,7 +1683,7 @@ int pretty_size_snprintf(u64 size, char *str, size_t str_size, unsigned unit_mod
}
/*
* __strncpy__null - strncpy with null termination
* @dest: the target array
* @src: the source string
* @n: maximum bytes to copy (size of *dest)
@@ -1694,7 +1694,7 @@ int pretty_size_snprintf(u64 size, char *str, size_t str_size, unsigned unit_mod
* byte ('\0'), to the buffer pointed to by dest, up to a maximum
* of n bytes. Then ensure that dest is null-terminated.
*/
-char *__strncpy__null(char *dest, const char *src, size_t n)
+char *__strncpy_null(char *dest, const char *src, size_t n)
{
strncpy(dest, src, n);
if (n > 0)
@@ -2969,7 +2969,7 @@ int arg_copy_path(char *dest, const char *src, int destlen)
if (len >= PATH_MAX || len >= destlen)
return -ENAMETOOLONG;
- __strncpy__null(dest, src, destlen);
+ __strncpy_null(dest, src, destlen);
return 0;
}
@@ -1683,7 +1683,7 @@ int pretty_size_snprintf(u64 size, char *str, size_t str_size, unsigned unit_mod
}
/*
- * __strncpy__null - strncpy with null termination
+ * __strncpy_null - strncpy with null termination
* @dest: the target array
* @src: the source string